Welcome to Py-STAC Tools's documentation!
=========================================

Contents:

.. toctree::
    :maxdepth: 2

    readme
    installation
    usage
    modules
    contributing
    authors
    history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
